@@ -21,7 +21,8 @@ Settings::Settings()
     : _location(),
     _previous_locations(),
     _gps_enabled(true),
-    _search_objects_type(MOVIES)
+    _search_objects_type(MOVIES),
+    _rotation_mode(AUTOROTATION)
 {
 }
 
