@@ -107,7 +107,7 @@ void MovieSearchClient::ReplyFinished(QNetworkReply *reply)
                 }
             } else if (state == PARSE_EXPECT_DIV2 && xml.name() == "div") {
                 state = PARSE_DIV2;
-            } else if (state == PARSE_DIV2 && xml.name() == "span" && attr_class.isEmpty()) {
+            } else if (state == PARSE_DIV2 && xml.name() == "span") {
                 movie_spans.append("");
                 state = PARSE_SPAN;
             } else if (state == PARSE_DIV2 && xml.name() == "img") {
