@@ -14,7 +14,7 @@
         <translation>MovieSchedule</translation>
     </message>
     <message utf8="true">
-        <location filename="../ui/aboutdialog.ui" line="109"/>
+        <location filename="../ui/aboutdialog.ui" line="107"/>
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
@@ -95,13 +95,11 @@ p, li { white-space: pre-wrap; }
         <translation>Telefonanruf fehlgeschlagen: Kein Anruf möglich.</translation>
     </message>
     <message>
-        <location filename="../control/actioncontroller.cpp" line="221"/>
         <source>Unable to search in web: communication bus not available.</source>
-        <translation>Websuche fehlgeschlagen: Kommunikation mit Browser nicht möglich.</translation>
+        <translation type="obsolete">Websuche fehlgeschlagen: Kommunikation mit Browser nicht möglich.</translation>
     </message>
     <message>
-        <location filename="../control/actioncontroller.cpp" line="226"/>
-        <location filename="../control/actioncontroller.cpp" line="232"/>
+        <location filename="../control/actioncontroller.cpp" line="220"/>
         <source>Unable to search in web: browser service not available.</source>
         <translation>Websuche fehlgeschlagen: Browser steht nicht zur Verfügung.</translation>
     </message>
@@ -155,17 +153,17 @@ p, li { white-space: pre-wrap; }
         <translation>Ort</translation>
     </message>
     <message>
-        <location filename="../ui/locationdialog.ui" line="49"/>
+        <location filename="../ui/locationdialog.ui" line="34"/>
         <source>Search Near</source>
         <translation>In der Nähe suchen</translation>
     </message>
     <message>
-        <location filename="../ui/locationdialog.ui" line="116"/>
+        <location filename="../ui/locationdialog.ui" line="100"/>
         <source>City</source>
         <translation>Stadt</translation>
     </message>
     <message>
-        <location filename="../ui/locationdialog.ui" line="149"/>
+        <location filename="../ui/locationdialog.ui" line="135"/>
         <source>Search</source>
         <translation>Suchen</translation>
     </message>
@@ -177,27 +175,27 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Netzwerk steht nicht zur Verfügung.</translation>
     </message>
     <message>
-        <location filename="../control/maincontroller.cpp" line="43"/>
+        <location filename="../control/maincontroller.cpp" line="44"/>
         <source>Unable to access network.</source>
         <translation>Netzwerk steht nicht zur Verfügung.</translation>
     </message>
     <message>
-        <location filename="../control/maincontroller.cpp" line="44"/>
+        <location filename="../control/maincontroller.cpp" line="45"/>
         <source>No theaters found near %1.</source>
         <translation>Keine Kinos in der Nähe von %1 gefunden.</translation>
     </message>
     <message>
-        <location filename="../control/maincontroller.cpp" line="45"/>
+        <location filename="../control/maincontroller.cpp" line="46"/>
         <source>No movies found near %1.</source>
         <translation>Keine Filme in der Nähe von %1 gefunden.</translation>
     </message>
     <message>
-        <location filename="../control/maincontroller.cpp" line="46"/>
+        <location filename="../control/maincontroller.cpp" line="47"/>
         <source>Error on fetching theaters.</source>
         <translation>Fehler beim Lesen der Kinoliste.</translation>
     </message>
     <message>
-        <location filename="../control/maincontroller.cpp" line="47"/>
+        <location filename="../control/maincontroller.cpp" line="48"/>
         <source>Error on fetching movies.</source>
         <translation>Fehler beim Lesen der Filmliste.</translation>
     </message>
@@ -206,13 +204,13 @@ p, li { white-space: pre-wrap; }
     <name>MainWindow</name>
     <message>
         <location filename="../ui/mainwindow.cpp" line="75"/>
-        <location filename="../ui/mainwindow.cpp" line="113"/>
+        <location filename="../ui/mainwindow.cpp" line="133"/>
         <source>Movies</source>
         <translation>Filme</translation>
     </message>
     <message>
         <location filename="../ui/mainwindow.cpp" line="76"/>
-        <location filename="../ui/mainwindow.cpp" line="105"/>
+        <location filename="../ui/mainwindow.cpp" line="125"/>
         <source>Theaters</source>
         <translation>Kinos</translation>
     </message>
@@ -223,22 +221,27 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="../ui/mainwindow.cpp" line="78"/>
+        <source>Options</source>
+        <translation>Einstellungen</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainwindow.cpp" line="79"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.cpp" line="80"/>
+        <location filename="../ui/mainwindow.cpp" line="81"/>
         <source>Call By Phone</source>
         <translation>Kino anrufen</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.cpp" line="81"/>
+        <location filename="../ui/mainwindow.cpp" line="82"/>
         <source>Find Route</source>
         <translation>Weg zum Kino suchen</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.cpp" line="82"/>
-        <location filename="../ui/mainwindow.cpp" line="84"/>
+        <location filename="../ui/mainwindow.cpp" line="83"/>
+        <location filename="../ui/mainwindow.cpp" line="85"/>
         <source>Search In Web</source>
         <translation>Im Web suchen</translation>
     </message>
@@ -248,7 +251,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="../ui/mainwindow.ui" line="14"/>
-        <location filename="../ui/mainwindow.cpp" line="120"/>
+        <location filename="../ui/mainwindow.cpp" line="140"/>
         <source>MovieSchedule</source>
         <translation>MovieSchedule</translation>
     </message>
@@ -274,6 +277,39 @@ p, li { white-space: pre-wrap; }
         <translation>Film</translation>
     </message>
 </context>
+<context>
+    <name>OptionsDialog</name>
+    <message>
+        <location filename="../ui/optionsdialog.ui" line="14"/>
+        <source>Options</source>
+        <translation>Einstellungen</translation>
+    </message>
+    <message>
+        <location filename="../ui/optionsdialog.ui" line="22"/>
+        <source>Orientation</source>
+        <translation>Orientierung</translation>
+    </message>
+    <message>
+        <location filename="../ui/optionsdialog.ui" line="54"/>
+        <source>Done</source>
+        <translation>Fertig</translation>
+    </message>
+    <message>
+        <location filename="../ui/optionsdialog.cpp" line="32"/>
+        <source>Landscape</source>
+        <translation>Querformat</translation>
+    </message>
+    <message>
+        <location filename="../ui/optionsdialog.cpp" line="33"/>
+        <source>Portrait</source>
+        <translation>Hochformat</translation>
+    </message>
+    <message>
+        <location filename="../ui/optionsdialog.cpp" line="34"/>
+        <source>Automatic Rotation</source>
+        <translation>Automatische Drehung</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
